@@ -12,7 +12,7 @@ extern "C" {
 	// Product function + wrapper
 	double prod(double *mydata, unsigned int size) {
 		double prodtotal = mydata[0];
-		for (register unsigned int i = 1; i < size; i++) {
+		for (unsigned int i = 1; i < size; i++) {
 			prodtotal *= mydata[i];
 		}
 		return prodtotal;
@@ -34,7 +34,7 @@ extern "C" {
 		double sumtotal = 0.;
 		double zero = 0;
 		//Rprintf("%f\n", mydata[0]);
-		for (register unsigned int i = 0; i < size; i++) {
+		for (unsigned int i = 0; i < size; i++) {
 
 			if (!ISNAN(mydata[i])) {
 				sumtotal += mydata[i];
@@ -61,7 +61,7 @@ extern "C" {
 	// Sum of powers function + wrapper
 	double sumpower(double *mydata, unsigned int size, int power) {
 		double sumpowertotal = 0.;
-		for (register unsigned int i = 0; i < size; i++) {
+		for (unsigned int i = 0; i < size; i++) {
 			sumpowertotal += pow(mydata[i], power);
 		}
 		return sumpowertotal;
